pub struct EuclideanClusterConfig {
pub cluster_tolerance: f32,
pub min_cluster_size: usize,
pub max_cluster_size: usize,
}Expand description
Configuration for Euclidean clustering.
Fields
cluster_tolerance: f32Maximum distance between points in the same cluster.
min_cluster_size: usizeMinimum number of points required to form a cluster.
max_cluster_size: usizeMaximum number of points allowed in a cluster.
Implementations
Sourceimpl EuclideanClusterConfig
impl EuclideanClusterConfig
Sourcepub const fn with_tolerance(
cluster_tolerance: f32,
min_cluster_size: usize,
) -> Self
pub const fn with_tolerance( cluster_tolerance: f32, min_cluster_size: usize, ) -> Self
Creates a config with the given tolerance and minimum cluster size.