PlaneModel

Struct PlaneModel 

pub struct PlaneModel {
    pub normal: Vec3<f32>,
    pub d: f32,
}
Plane model in Hessian form: normal · p + d = 0 with unit normal.

Fields

normal: Vec3<f32>

Unit-length plane normal.

d: f32

Plane offset term.

Implementations

Source

impl PlaneModel

pub fn signed_distance(&self, point: Vec3<f32>) -> f32

Returns the signed distance from a point to the plane.

pub fn distance(&self, point: Vec3<f32>) -> f32

Returns the absolute distance from a point to the plane.

pub fn distance_xyz(&self, x: f32, y: f32, z: f32) -> f32

Returns the absolute distance from XYZ coordinates to the plane.